@@ -27,7 +27,7 @@
 #'   should be displayed (`FALSE`).
 #' @param .stats (`character`)\cr statistics to select for the table.
 #'
-#'   Options are: ``r shQuote(get_stats("count_occurrences_by_grade"))``
+#'   Options are: ``r shQuote(get_stats("count_occurrences_by_grade"), type = "sh")``
 #'
 #' @seealso Relevant helper function [h_append_grade_groups()].
 #'
@@ -149,15 +149,16 @@ h_append_grade_groups <- function(grade_groups, refs, remove_single = TRUE, only
 #'
 #' @export
 s_count_occurrences_by_grade <- function(df,
+                                         labelstr = "",
                                          .var,
                                          .N_row, # nolint
                                          .N_col, # nolint
+                                         ...,
                                          id = "USUBJID",
                                          grade_groups = list(),
                                          remove_single = TRUE,
                                          only_grade_groups = FALSE,
-                                         denom = c("N_col", "n", "N_row"),
-                                         labelstr = "") {
+                                         denom = c("N_col", "n", "N_row")) {
   assert_valid_factor(df[[.var]])
   assert_df_with_variables(df, list(grade = .var, id = id))
 
@@ -248,56 +249,59 @@ s_count_occurrences_by_grade <- function(df,
 #' @export
 a_count_occurrences_by_grade <- function(df,
                                          labelstr = "",
-                                         id = "USUBJID",
-                                         grade_groups = list(),
-                                         remove_single = TRUE,
-                                         only_grade_groups = FALSE,
-                                         denom = c("N_col", "n", "N_row"),
-                                         .N_col, # nolint
-                                         .N_row, # nolint
-                                         .df_row,
-                                         .var = NULL,
+                                         ...,
                                          .stats = NULL,
+                                         .stat_names = NULL,
                                          .formats = NULL,
                                          .labels = NULL,
-                                         .indent_mods = NULL,
-                                         na_str = default_na_str()) {
-  x_stats <- s_count_occurrences_by_grade(
-    df = df, .var = .var, .N_row = .N_row, .N_col = .N_col, id = id,
-    grade_groups = grade_groups, remove_single = remove_single, only_grade_groups = only_grade_groups,
-    denom = denom, labelstr = labelstr
+                                         .indent_mods = NULL) {
+  # Check for additional parameters to the statistics function
+  dots_extra_args <- list(...)
+  extra_afun_params <- retrieve_extra_afun_params(names(dots_extra_args$.additional_fun_parameters))
+  dots_extra_args$.additional_fun_parameters <- NULL
+
+  # Check for user-defined functions
+  default_and_custom_stats_list <- .split_std_from_custom_stats(.stats)
+  .stats <- default_and_custom_stats_list$all_stats
+  custom_stat_functions <- default_and_custom_stats_list$custom_stats
+
+  # Apply statistics function
+  x_stats <- .apply_stat_functions(
+    default_stat_fnc = s_count_occurrences_by_grade,
+    custom_stat_fnc_list = custom_stat_functions,
+    args_list = c(
+      df = list(df),
+      labelstr = list(labelstr),
+      extra_afun_params,
+      dots_extra_args
+    )
   )
 
-  if (is.null(unlist(x_stats))) {
-    return(NULL)
-  }
-
-  # Fill in with formatting defaults if needed
-  .stats <- get_stats("count_occurrences_by_grade", stats_in = .stats)
-  if (length(.formats) == 1 && is.null(names(.formats))) {
-    .formats <- rep(.formats, length(.stats)) %>% setNames(.stats)
-  }
-  .formats <- get_formats_from_stats(.stats, .formats)
-  .labels <- .unlist_keep_nulls(get_labels_from_stats(.stats, .labels, lapply(x_stats, names)))
-  .indent_mods <- get_indents_from_stats(.stats, .indent_mods, row_nms = names(x_stats[[1]]))
-
+  # Fill in formatting defaults
+  .stats <- get_stats("count_occurrences_by_grade", stats_in = .stats, custom_stats_in = names(custom_stat_functions))
   x_stats <- x_stats[.stats]
+  levels_per_stats <- lapply(x_stats, names)
+  .formats <- get_formats_from_stats(.stats, .formats, levels_per_stats)
+  .labels <- get_labels_from_stats(.stats, .labels, levels_per_stats)
+  .indent_mods <- get_indents_from_stats(.stats, .indent_mods, levels_per_stats)
 
-  # Ungroup statistics with values for each level of x
-  x_ungrp <- ungroup_stats(x_stats, .formats, list())
-  x_stats <- x_ungrp[["x"]]
-  .formats <- x_ungrp[[".formats"]]
+  x_stats <- x_stats[.stats] %>%
+    .unlist_keep_nulls() %>%
+    setNames(names(.formats))
 
   # Auto format handling
-  .formats <- apply_auto_formatting(.formats, x_stats, .df_row, .var)
+  .formats <- apply_auto_formatting(.formats, x_stats, extra_afun_params$.df_row, extra_afun_params$.var)
+
+  # Get and check statistical names
+  .stat_names <- get_stat_names(x_stats, .stat_names)
 
   in_rows(
     .list = x_stats,
     .formats = .formats,
-    .names = .labels,
-    .labels = .labels,
-    .indent_mods = .indent_mods,
-    .format_na_strs = na_str
+    .names = .labels %>% .unlist_keep_nulls(),
+    .stat_names = .stat_names,
+    .labels = .labels %>% .unlist_keep_nulls(),
+    .indent_mods = .indent_mods %>% .unlist_keep_nulls()
   )
 }
 
@@ -370,39 +374,42 @@ count_occurrences_by_grade <- function(lyt,
                                        ...,
                                        table_names = var,
                                        .stats = "count_fraction",
+                                       .stat_names = NULL,
                                        .formats = list(count_fraction = format_count_fraction_fixed_dp),
-                                       .indent_mods = NULL,
-                                       .labels = NULL) {
+                                       .labels = NULL,
+                                       .indent_mods = NULL) {
   checkmate::assert_flag(riskdiff)
-  extra_args <- list(
-    .stats = .stats, .formats = .formats, .labels = .labels, .indent_mods = .indent_mods, na_str = na_str
-  )
-  s_args <- list(
-    id = id, grade_groups = grade_groups, remove_single = remove_single, only_grade_groups = only_grade_groups, ...
+  afun <- if (isFALSE(riskdiff)) a_count_occurrences_by_grade else afun_riskdiff
+
+  # Process standard extra arguments
+  extra_args <- list(".stats" = .stats)
+  if (!is.null(.stat_names)) extra_args[[".stat_names"]] <- .stat_names
+  if (!is.null(.formats)) extra_args[[".formats"]] <- .formats
+  if (!is.null(.labels)) extra_args[[".labels"]] <- .labels
+  if (!is.null(.indent_mods)) extra_args[[".indent_mods"]] <- .indent_mods
+
+  # Process additional arguments to the statistic function
+  extra_args <- c(
+    extra_args,
+    id = id, grade_groups = list(grade_groups), remove_single = remove_single, only_grade_groups = only_grade_groups,
+    if (!isFALSE(riskdiff)) list(afun = list("s_count_occurrences_by_grade" = a_count_occurrences_by_grade)),
+    ...
   )
 
-  if (isFALSE(riskdiff)) {
-    extra_args <- c(extra_args, s_args)
-  } else {
-    extra_args <- c(
-      extra_args,
-      list(
-        afun = list("s_count_occurrences_by_grade" = a_count_occurrences_by_grade),
-        s_args = s_args
-      )
-    )
-  }
+  # Append additional info from layout to the analysis function
+  extra_args[[".additional_fun_parameters"]] <- get_additional_afun_params(add_alt_df = FALSE)
+  formals(afun) <- c(formals(afun), extra_args[[".additional_fun_parameters"]])
 
   analyze(
     lyt = lyt,
     vars = var,
-    afun = ifelse(isFALSE(riskdiff), a_count_occurrences_by_grade, afun_riskdiff),
-    var_labels = var_labels,
-    show_labels = show_labels,
-    table_names = table_names,
+    afun = afun,
     na_str = na_str,
     nested = nested,
-    extra_args = extra_args
+    extra_args = extra_args,
+    var_labels = var_labels,
+    show_labels = show_labels,
+    table_names = table_names
   )
 }
 
@@ -446,34 +453,45 @@ summarize_occurrences_by_grade <- function(lyt,
                                            na_str = default_na_str(),
                                            ...,
                                            .stats = "count_fraction",
+                                           .stat_names = NULL,
                                            .formats = list(count_fraction = format_count_fraction_fixed_dp),
-                                           .indent_mods = NULL,
-                                           .labels = NULL) {
+                                           .labels = NULL,
+                                           .indent_mods = 0L) {
   checkmate::assert_flag(riskdiff)
-  extra_args <- list(
-    .stats = .stats, .formats = .formats, .labels = .labels, .indent_mods = .indent_mods, na_str = na_str
-  )
-  s_args <- list(
-    id = id, grade_groups = grade_groups, remove_single = remove_single, only_grade_groups = only_grade_groups, ...
+  afun <- if (isFALSE(riskdiff)) a_count_occurrences_by_grade else afun_riskdiff
+
+  # Process standard extra arguments
+  extra_args <- list(".stats" = .stats)
+  if (!is.null(.stat_names)) extra_args[[".stat_names"]] <- .stat_names
+  if (!is.null(.formats)) extra_args[[".formats"]] <- .formats
+  if (!is.null(.labels)) extra_args[[".labels"]] <- .labels
+  if (is.null(.indent_mods)) {
+    indent_mod <- 0L
+  } else if (length(.indent_mods) == 1) {
+    indent_mod <- .indent_mods
+  } else {
+    indent_mod <- 0L
+    extra_args[[".indent_mods"]] <- .indent_mods
+  }
+
+  # Process additional arguments to the statistic function
+  extra_args <- c(
+    extra_args,
+    id = id, grade_groups = list(grade_groups), remove_single = remove_single, only_grade_groups = only_grade_groups,
+    if (!isFALSE(riskdiff)) list(afun = list("s_count_occurrences_by_grade" = a_count_occurrences_by_grade)),
+    ...
   )
 
-  if (isFALSE(riskdiff)) {
-    extra_args <- c(extra_args, s_args)
-  } else {
-    extra_args <- c(
-      extra_args,
-      list(
-        afun = list("s_count_occurrences_by_grade" = a_count_occurrences_by_grade),
-        s_args = s_args
-      )
-    )
-  }
+  # Append additional info from layout to the analysis function
+  extra_args[[".additional_fun_parameters"]] <- get_additional_afun_params(add_alt_df = FALSE)
+  formals(afun) <- c(formals(afun), extra_args[[".additional_fun_parameters"]])
 
   summarize_row_groups(
     lyt = lyt,
     var = var,
-    cfun = ifelse(isFALSE(riskdiff), a_count_occurrences_by_grade, afun_riskdiff),
+    cfun = afun,
     na_str = na_str,
-    extra_args = extra_args
+    extra_args = extra_args,
+    indent_mod = indent_mod
   )
 }
