@@ -16,7 +16,7 @@
 #' @param scale (`numeric(1)`)\cr linear scaling factor for rate and confidence intervals. Defaults to `1`.
 #' @param .stats (`character`)\cr statistics to select for the table.
 #'
-#'   Options are: ``r shQuote(get_stats("summarize_glm_count"))``
+#'   Options are: ``r shQuote(get_stats("summarize_glm_count"), type = "sh")``
 #'
 #' @details
 #' `summarize_glm_count()` uses `s_glm_count()` to calculate the statistics for the table. This
@@ -117,48 +117,42 @@ summarize_glm_count <- function(lyt,
                                 ...,
                                 show_labels = "visible",
                                 table_names = vars,
-                                .stats = get_stats("summarize_glm_count"),
+                                .stats = c("n", "rate", "rate_ci", "rate_ratio", "rate_ratio_ci", "pval"),
+                                .stat_names = NULL,
                                 .formats = NULL,
                                 .labels = NULL,
-                                .indent_mods = c(
-                                  "n" = 0L,
-                                  "rate" = 0L,
-                                  "rate_ci" = 1L,
-                                  "rate_ratio" = 0L,
-                                  "rate_ratio_ci" = 1L,
-                                  "pval" = 1L
-                                )) {
+                                .indent_mods = list("rate_ci" = 1L, "rate_ratio_ci" = 1L, "pval" = 1L)) {
   checkmate::assert_choice(rate_mean_method, c("emmeans", "ppmeans"))
 
-  extra_args <- list(
-    variables = variables, distribution = distribution, conf_level = conf_level,
-    rate_mean_method = rate_mean_method, weights = weights, scale = scale, ...
+  # Process standard extra arguments
+  extra_args <- list(".stats" = .stats)
+  if (!is.null(.stat_names)) extra_args[[".stat_names"]] <- .stat_names
+  if (!is.null(.formats)) extra_args[[".formats"]] <- .formats
+  if (!is.null(.labels)) extra_args[[".labels"]] <- .labels
+  if (!is.null(.indent_mods)) extra_args[[".indent_mods"]] <- .indent_mods
+
+  # Process additional arguments to the statistic function
+  extra_args <- c(
+    extra_args,
+    variables = list(variables), distribution = list(distribution), conf_level = list(conf_level),
+    rate_mean_method = list(rate_mean_method), weights = list(weights), scale = list(scale),
+    ...
   )
 
-  # Selecting parameters following the statistics
-  .formats <- get_formats_from_stats(.stats, formats_in = .formats)
-  .labels <- get_labels_from_stats(.stats, labels_in = .labels)
-  .indent_mods <- get_indents_from_stats(.stats, indents_in = .indent_mods)
-
-  afun <- make_afun(
-    s_glm_count,
-    .stats = .stats,
-    .formats = .formats,
-    .labels = .labels,
-    .indent_mods = .indent_mods,
-    .null_ref_cells = FALSE
-  )
+  # Append additional info from layout to the analysis function
+  extra_args[[".additional_fun_parameters"]] <- get_additional_afun_params(add_alt_df = FALSE)
+  formals(a_glm_count) <- c(formals(a_glm_count), extra_args[[".additional_fun_parameters"]])
 
   analyze(
-    lyt,
-    vars,
-    var_labels = var_labels,
-    show_labels = show_labels,
-    table_names = table_names,
-    afun = afun,
+    lyt = lyt,
+    vars = vars,
+    afun = a_glm_count,
     na_str = na_str,
     nested = nested,
-    extra_args = extra_args
+    extra_args = extra_args,
+    var_labels = var_labels,
+    show_labels = show_labels,
+    table_names = table_names
   )
 }
 
@@ -178,14 +172,15 @@ summarize_glm_count <- function(lyt,
 s_glm_count <- function(df,
                         .var,
                         .df_row,
-                        variables,
                         .ref_group,
                         .in_ref_col,
+                        variables,
                         distribution,
                         conf_level,
                         rate_mean_method,
                         weights,
-                        scale = 1) {
+                        scale = 1,
+                        ...) {
   arm <- variables$arm
 
   y <- df[[.var]]
@@ -222,9 +217,9 @@ s_glm_count <- function(df,
         c(emmeans_smry_level$asymp.LCL * scale, emmeans_smry_level$asymp.UCL * scale),
         f_conf_level(conf_level)
       ),
-      rate_ratio = formatters::with_label(character(), "Adjusted Rate Ratio"),
-      rate_ratio_ci = formatters::with_label(character(), f_conf_level(conf_level)),
-      pval = formatters::with_label(character(), "p-value")
+      rate_ratio = formatters::with_label(numeric(), "Adjusted Rate Ratio"),
+      rate_ratio_ci = formatters::with_label(numeric(), f_conf_level(conf_level)),
+      pval = formatters::with_label(numeric(), "p-value")
     )
   } else {
     emmeans_contrasts <- emmeans::contrast(
@@ -272,7 +267,70 @@ s_glm_count <- function(df,
     )
   }
 }
+
+#' @describeIn summarize_glm_count Formatted analysis function which is used as `afun` in `summarize_glm_count()`.
+#'
+#' @return
+#' * `a_glm_count()` returns the corresponding list with formatted [rtables::CellValue()].
+#'
+#' @keywords internal
+a_glm_count <- function(df,
+                        ...,
+                        .stats = NULL,
+                        .stat_names = NULL,
+                        .formats = NULL,
+                        .labels = NULL,
+                        .indent_mods = NULL) {
+  # Check for additional parameters to the statistics function
+  dots_extra_args <- list(...)
+  extra_afun_params <- retrieve_extra_afun_params(names(dots_extra_args$.additional_fun_parameters))
+  dots_extra_args$.additional_fun_parameters <- NULL
+
+  # Check for user-defined functions
+  default_and_custom_stats_list <- .split_std_from_custom_stats(.stats)
+  .stats <- default_and_custom_stats_list$all_stats
+  custom_stat_functions <- default_and_custom_stats_list$custom_stats
+
+  # Apply statistics function
+  x_stats <- .apply_stat_functions(
+    default_stat_fnc = s_glm_count,
+    custom_stat_fnc_list = custom_stat_functions,
+    args_list = c(
+      df = list(df),
+      extra_afun_params,
+      dots_extra_args
+    )
+  )
+
+  # Fill in formatting defaults
+  .stats <- get_stats("summarize_glm_count",
+    stats_in = .stats,
+    custom_stats_in = names(custom_stat_functions)
+  )
+  .formats <- get_formats_from_stats(.stats, .formats)
+  .labels <- get_labels_from_stats(.stats, .labels)
+  .indent_mods <- get_indents_from_stats(.stats, .indent_mods)
+
+  x_stats <- x_stats[.stats]
+
+  # Auto format handling
+  .formats <- apply_auto_formatting(.formats, x_stats, extra_afun_params$.df_row, extra_afun_params$.var)
+
+  # Get and check statistical names
+  .stat_names <- get_stat_names(x_stats, .stat_names)
+
+  in_rows(
+    .list = x_stats,
+    .formats = .formats,
+    .names = .labels %>% .unlist_keep_nulls(),
+    .stat_names = .stat_names,
+    .labels = .labels %>% .unlist_keep_nulls(),
+    .indent_mods = .indent_mods %>% .unlist_keep_nulls()
+  )
+}
+
 # h_glm_count ------------------------------------------------------------------
+
 #' Helper functions for Poisson models
 #'
 #' @description `r lifecycle::badge("experimental")`
